@@ -9,7 +9,7 @@ from thonny.shell import ShellText
 from thonny import get_workbench, get_shell
 
 
-from .common import common_postit_tabs, common_images
+from .common import common_images
 
 class BaseWidget(ttk.Frame):
 
@@ -24,7 +24,7 @@ class BaseWidget(ttk.Frame):
         """
         # store tab
         self.tab_name = tab_name
-        self.tab = common_postit_tabs[tab_name]
+        self.tab = common.postit_tabs[tab_name]
         
 
         # image
@@ -127,6 +127,7 @@ class BasePost:
         self.drag_window = None
         self.drag_button = None
         self.drag_hover_selection = False
+        self.hover_text_backup = ''
         #self.mouse_dragging = False
         # drag and press event
         self.postit_button.bind("<B1-Motion>", self.on_mouse_drag)
@@ -142,7 +143,7 @@ class BasePost:
 
         x_root, y_root = event.x_root, event.y_root
 
-        self.drag_window.geometry('+{}+{}'.format(x_root+18, y_root+5))
+        self.drag_window.geometry('+{}+{}'.format(x_root-10, y_root+10))
 
         #change insert over editor or shell (but not postit button)
         
@@ -163,10 +164,12 @@ class BasePost:
                 if editor_text.compare(tk.SEL_FIRST, "<=", mouse_index) and \
                     editor_text.compare(mouse_index, "<=", tk.SEL_LAST):
                     self.drag_hover_selection = True
-                    self.drag_button.config(bd=2)
+                    #self.drag_button.config(text='【取代】'+self.hover_text_backup)
+                    
                 else:
                     self.drag_hover_selection = False
-                    self.drag_button.config(bd=0)
+                    #self.drag_button.config(text=self.hover_text_backup)
+                    
                     
         elif isinstance(hover_widget, ShellText):
             # hover shell 
@@ -185,10 +188,12 @@ class BasePost:
                     if shell_text.compare(tk.SEL_FIRST, "<=", mouse_index) and \
                         shell_text.compare(mouse_index, "<=", tk.SEL_LAST):
                         self.drag_hover_selection = True
-                        self.drag_button.config(bd=3)
+                        #self.drag_button.config(text='【取代】'+self.hover_text_backup)
+                        
                     else:
                         self.drag_hover_selection = False
-                        self.drag_button.config(bd=0)
+                        #self.drag_button.config(text=self.hover_text_backup)
+                        
 
     def create_drag_window(self):
             self.drag_window = tk.Toplevel()
@@ -198,7 +203,8 @@ class BasePost:
             font = self.postit_button.cget('font')
             bg = self.postit_button.cget('bg')
             fg = self.postit_button.cget('fg')
-            text = self.postit_button.cget('text')
+            text = '  ' + self.postit_button.cget('text')
+            #self.hover_text_backup = text
             justify = self.postit_button.cget('justify')
             self.drag_button = tk.Button(self.drag_window, text=text, bg=bg, 
                         fg=fg,font=font, compound=compound, image=image,
@@ -337,8 +343,9 @@ class BasePost:
                 #if else else and except, need to add a extra backspack
                 # pass is special case
                 #if not line.startswith('pass'):
-                if line[:4] in ('else', 'elif', 'exce')  :
-                    text_widget.event_generate("<BackSpace>")
+                
+                #if line[:4] in ('else', 'elif', 'exce')  :
+                #    text_widget.event_generate("<BackSpace>")
 
                 text_widget.insert(tk.INSERT,line)
 
@@ -408,7 +415,7 @@ class BasePost:
 class BasePopup:
     def popup_init(self):
         self.popup_menu = tk.Menu(self, tearoff=0)
-        self.popup_menu.add_checkbutton(label="【選項】結尾Enter換行", onvalue=1, offvalue=0, 
+        self.popup_menu.add_checkbutton(label="加上Enter換行", onvalue=1, offvalue=0, 
                 variable=self.var_postfix_enter,
                 command=self.toggle_postfix_enter,
                 )
